@@ -1,4 +1,4 @@
-# $Id: CheckOS.pm,v 1.28 2008/10/22 19:10:52 drhyde Exp $
+# $Id: CheckOS.pm,v 1.30 2008/10/27 20:31:21 drhyde Exp $
 
 package Devel::CheckOS;
 
@@ -7,7 +7,7 @@ use Exporter;
 
 use vars qw($VERSION @ISA @EXPORT_OK %EXPORT_TAGS);
 
-$VERSION = '1.45';
+$VERSION = '1.46';
 
 # localising prevents the warningness leaking out of this module
 local $^W = 1;    # use warnings is a 5.6-ism
@@ -187,9 +187,9 @@ sub list_platforms {
             last;
         }
         {
-	    module => join('::', @dirs, $file_part),
-	    file   => $_
-	}
+            module => join('::', @dirs, $file_part),
+            file   => File::Spec->canonpath($_)
+        }
     } File::Find::Rule->file()->name('*.pm')->in(
         grep { -d }
         map { File::Spec->catdir($_, qw(Devel AssertOS)) }
@@ -270,6 +270,9 @@ Thanks to Billy Abbott for finding some bugs for me on VMS.
 
 Thanks to Matt Kraai for information about QNX.
 
+Thanks to Kenichi Ishigaki and Gabor Szabo for reporting a bug on Windows,
+and to the former for providing a patch.
+
 =head1 CVS
 
 L<http://drhyde.cvs.sourceforge.net/drhyde/perlmodules/Devel-CheckOS/>
